@@ -18,7 +18,7 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#  include "../cutter/config.h"
+#  include <config.h>
 #endif /* HAVE_CONFIG_H */
 
 #include <glib.h>
@@ -26,6 +26,7 @@
 
 #include "gcut-main.h"
 #include "gcut-value-equal.h"
+#include <cutter/cut-helper.h>
 
 typedef struct {
     GType type1;
@@ -143,7 +144,11 @@ value_equal_ ## type ## _ ## type (gconstpointer val1,                  \
         g_value_get_ ## type(value2);                                   \
 }
 
+#if GLIB_CHECK_VERSION(2, 32, 0)
+DEFINE_SAME_TYPE_EQUAL_FUNC(schar)
+#else
 DEFINE_SAME_TYPE_EQUAL_FUNC(char)
+#endif
 DEFINE_SAME_TYPE_EQUAL_FUNC(uchar)
 DEFINE_SAME_TYPE_EQUAL_FUNC(boolean)
 DEFINE_SAME_TYPE_EQUAL_FUNC(int)
@@ -163,8 +168,8 @@ value_equal_string_string (gconstpointer val1, gconstpointer val2)
     const GValue *value1 = val1;
     const GValue *value2 = val2;
 
-    return g_str_equal(g_value_get_string(value1),
-                       g_value_get_string(value2));
+    return cut_equal_string(g_value_get_string(value1),
+                            g_value_get_string(value2));
 }
 
 void
@@ -176,7 +181,11 @@ gcut_value_equal_init (void)
     gcut_value_register_equal_func(g_type, g_type,                      \
                                    value_equal_ ## type ## _ ## type)
 
+#if GLIB_CHECK_VERSION(2, 32, 0)
+    REGISTER_SAME_TYPE_EQUAL_FUNC(G_TYPE_CHAR, schar);
+#else
     REGISTER_SAME_TYPE_EQUAL_FUNC(G_TYPE_CHAR, char);
+#endif
     REGISTER_SAME_TYPE_EQUAL_FUNC(G_TYPE_UCHAR, uchar);
     REGISTER_SAME_TYPE_EQUAL_FUNC(G_TYPE_BOOLEAN, boolean);
     REGISTER_SAME_TYPE_EQUAL_FUNC(G_TYPE_INT, int);
