@@ -18,7 +18,7 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#  include <config.h>
 #endif /* HAVE_CONFIG_H */
 
 #include "gst-cutter-server.h"
@@ -30,11 +30,6 @@
 GST_DEBUG_CATEGORY_STATIC(cutter_server_debug);
 #define GST_CAT_DEFAULT cutter_server_debug
 
-static const GstElementDetails cutter_server_details =
-    GST_ELEMENT_DETAILS("Cutter test server",
-                        "Cutter test server",
-                        "Cutter test server",
-                        "g新部 Hiroyuki Ikezoe  <poincare@ikezoe.net>");
 static GstStaticPadTemplate cutter_server_src_template_factory =
     GST_STATIC_PAD_TEMPLATE("src",
                             GST_PAD_SRC,
@@ -64,7 +59,8 @@ struct _GstCutterServerPrivate
     GstPad *sink_pad;
 };
 
-GST_BOILERPLATE(GstCutterServer, gst_cutter_server, GstElement, GST_TYPE_ELEMENT);
+#define gst_cutter_server_parent_class parent_class
+G_DEFINE_TYPE(GstCutterServer, gst_cutter_server, GST_TYPE_ELEMENT);
 
 enum
 {
@@ -87,19 +83,6 @@ static void get_property   (GObject         *object,
 static GstStateChangeReturn change_state (GstElement *element,
                                           GstStateChange transition);
 
-static void
-gst_cutter_server_base_init (gpointer klass)
-{
-    GstElementClass *element_class = GST_ELEMENT_CLASS(klass);
-
-    gst_element_class_add_pad_template(element_class,
-        gst_static_pad_template_get(&cutter_server_src_template_factory));
-    gst_element_class_add_pad_template(element_class,
-        gst_static_pad_template_get(&cutter_server_sink_template_factory));
-
-    gst_element_class_set_details(element_class, &cutter_server_details);
-}
-
 static void
 gst_cutter_server_class_init (GstCutterServerClass * klass)
 {
@@ -141,19 +124,30 @@ gst_cutter_server_class_init (GstCutterServerClass * klass)
     g_type_class_add_private(gobject_class, sizeof(GstCutterServerPrivate));
 
     GST_DEBUG_CATEGORY_INIT(cutter_server_debug, "cutter-test", 0, "Cutter test elements");
+
+    gst_element_class_add_pad_template(element_class,
+        gst_static_pad_template_get(&cutter_server_src_template_factory));
+    gst_element_class_add_pad_template(element_class,
+        gst_static_pad_template_get(&cutter_server_sink_template_factory));
+
+    gst_element_class_set_metadata(element_class,
+                                   "Cutter test server",
+                                   "Cutter test server",
+                                   "Cutter test server",
+                                   "g新部 Hiroyuki Ikezoe  <poincare@ikezoe.net>");
 }
 
 static void
-gst_cutter_server_init (GstCutterServer *cutter_server, GstCutterServerClass * klass)
+gst_cutter_server_init (GstCutterServer *cutter_server)
 {
     GstPadTemplate *pad_template;
     GstCutterServerPrivate *priv = GST_CUTTER_SERVER_GET_PRIVATE(cutter_server);
 
-    pad_template = gst_element_class_get_pad_template(GST_ELEMENT_CLASS(klass), "src");
+    pad_template = gst_element_class_get_pad_template(GST_ELEMENT_CLASS(cutter_server), "src");
     priv->src_pad = gst_pad_new_from_template(pad_template, "src");
     gst_element_add_pad(GST_ELEMENT(cutter_server), priv->src_pad);
 
-    pad_template = gst_element_class_get_pad_template(GST_ELEMENT_CLASS(klass), "sink");
+    pad_template = gst_element_class_get_pad_template(GST_ELEMENT_CLASS(cutter_server), "sink");
     priv->sink_pad = gst_pad_new_from_template(pad_template, "sink");
     gst_element_add_pad(GST_ELEMENT(cutter_server), priv->sink_pad);
 
