@@ -27,11 +27,11 @@ ensure
 end
 
 def login(agent, user_name, password=nil)
-  page = agent.get("https://sourceforge.net/account/login.php")
+  page = agent.get("https://sourceforge.net/auth/")
 
-  login_form = page.form("login_userpw")
-  login_form.form_loginname = user_name
-  login_form.form_pw = password || yield
+  login_form = page.forms.find {|form| /login/ =~ form.action}
+  login_form.username = user_name
+  login_form.password = password || yield
 
   begin
     page = agent.submit(login_form, login_form.buttons.first)
@@ -79,8 +79,8 @@ def go_development_page(agent, project_page, project_id)
 end
 
 def extract_sections(file)
-  normalized_text = File.read(file).gsub(/==+\n.*\n==+\n/, '')
-  normalized_text.split(/.*\n^(?:==\s+|=+$).*\n\n\n*/)
+  normalized_text = File.read(file).gsub(/[=#]{2,}\n.*\n[=#]{2,}\n/, '')
+  normalized_text.split(/.*\n^(?:[=#]{2}\s+|[=#]+$).*\n\n\n*/)
 end
 
 def guess_target_index(file, default_index)
@@ -107,12 +107,12 @@ def remove_rd_link_markup(text)
 end
 
 def go_news_page(agent, development_page)
-  agent.click(development_page.links.find {|link| /\ANews\z/ =~ link.text})
+  agent.click(development_page.links.find {|link| /\ANews\z/ =~ link.text.strip})
 end
 
 def go_submit_news_page(agent, news_page)
   submit_news_page_link = news_page.links.find do |link|
-    /\bnews\b/ =~ link.href and /\ANew Post\z/ =~ link.text
+    /\bnews\b/ =~ link.href and /\ANew Post\z/ =~ link.text.strip
   end
   agent.click(submit_news_page_link)
 end
