@@ -1,6 +1,6 @@
 /* -*- Mode: C; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
- *  Copyright (C) 2007-2011  Kouhei Sutou <kou@clear-code.com>
+ *  Copyright (C) 2007-2012  Kouhei Sutou <kou@clear-code.com>
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -33,6 +33,7 @@
 #include <cutter/cut-module-impl.h>
 #include <cutter/cut-listener.h>
 #include <cutter/cut-ui.h>
+#include <cutter/cut-utils.h>
 #include <cutter/cut-test-result.h>
 #include <cutter/cut-test.h>
 #include <cutter/cut-test-case.h>
@@ -40,6 +41,7 @@
 #include <cutter/cut-enum-types.h>
 #include <cutter/cut-pipeline.h>
 #include <cutter/cut-backtrace-entry.h>
+#include <cutter/cut-logger.h>
 
 #define CUT_TYPE_GTK_UI            cut_type_gtk_ui
 #define CUT_GTK_UI(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), CUT_TYPE_GTK_UI, CutGtkUI))
@@ -210,10 +212,12 @@ pop_message (CutGtkUI *ui, const gchar *context)
 static void
 remove_all_messages (CutGtkUI *ui, const gchar *context)
 {
+#if GTK_CHECK_VERSION(2, 22, 0)
     guint context_id;
 
     context_id = gtk_statusbar_get_context_id(ui->statusbar, context);
     gtk_statusbar_remove_all(ui->statusbar, context_id);
+#endif
 }
 
 static void
@@ -253,6 +257,189 @@ cb_cancel_or_restart (GtkToolButton *button, gpointer data)
     }
 }
 
+static void
+cb_quit (GtkWidget *widget, gpointer data)
+{
+    CutGtkUI *ui = CUT_GTK_UI(data);
+
+    gtk_widget_destroy(ui->window);
+}
+
+static void
+cb_run_all_tests (GtkWidget *widget, gpointer data)
+{
+    CutGtkUI *ui = CUT_GTK_UI(data);
+
+    cb_cancel_or_restart(GTK_TOOL_BUTTON(ui->cancel_or_restart_button),
+                         (gpointer)ui);
+}
+
+static void
+cb_run_test (GtkWidget *widget, gpointer data)
+{
+}
+
+#define CUT_WEBSITE_EN "http://cutter.sourceforge.net/"
+#define CUT_WEBSITE_JA "http://cutter.sourceforge.net/index.html.ja"
+#define CUT_TUTORIAL_EN "http://cutter.sourceforge.net/reference/tutorial.html"
+#define CUT_TUTORIAL_JA "http://cutter.sourceforge.net/reference/ja/tutorial.html"
+#define CUT_REFERENCE_EN "http://cutter.sourceforge.net/reference/"
+#define CUT_REFERENCE_JA "http://cutter.sourceforge.net/reference/ja/"
+
+static void
+show_uri_fallback (const gchar *uri)
+{
+#ifdef CUT_FALLBACK_BROWSER
+    GError *error = NULL;
+    GPtrArray *args;
+
+    args = g_ptr_array_new();
+    g_ptr_array_add(args, CUT_FALLBACK_BROWSER);
+    g_ptr_array_add(args, (gchar *)uri);
+    g_ptr_array_add(args, NULL);
+
+    g_spawn_async(NULL, (gchar **)args->pdata, NULL,
+                  G_SPAWN_SEARCH_PATH, NULL, NULL, NULL,
+                  &error);
+    g_ptr_array_unref(args);
+
+    if (!error)
+        return;
+
+    cut_log_warning("[ui][gtk] failed to show URI (fallback): <%s>: %s",
+                    uri, error->message);
+    g_error_free(error);
+#endif
+}
+
+static void
+show_uri (const gchar *uri)
+{
+    GError *error = NULL;
+
+    gtk_show_uri(NULL, uri, gtk_get_current_event_time(), &error);
+    if (!error)
+        return;
+
+    cut_log_warning("[ui][gtk] failed to show URI: <%s>: %s",
+                    uri, error->message);
+    g_error_free(error);
+
+    show_uri_fallback(uri);
+}
+
+static void
+cb_show_uri (GtkWidget *widget, gpointer data)
+{
+    GtkAction *action;
+    const gchar *name;
+    const gchar *uri = NULL;
+
+    action = GTK_ACTION(widget);
+    name = gtk_action_get_name(action);
+    if (strcmp(name, "WebsiteEn") == 0) {
+        uri = CUT_WEBSITE_EN;
+    } else if (strcmp(name, "WebsiteJa") == 0) {
+        uri = CUT_WEBSITE_JA;
+    } else if (strcmp(name, "TutorialEn") == 0) {
+        uri = CUT_TUTORIAL_EN;
+    } else if (strcmp(name, "TutorialJa") == 0) {
+        uri = CUT_TUTORIAL_JA;
+    } else if (strcmp(name, "ReferenceEn") == 0) {
+        uri = CUT_REFERENCE_EN;
+    } else if (strcmp(name, "ReferenceJa") == 0) {
+        uri = CUT_REFERENCE_JA;
+    }
+
+    if (!uri)
+        return;
+
+    show_uri(uri);
+}
+
+static GtkActionEntry menu_entries[] = {
+    /* name, stock_id, label, accelerator, tooltip, callback */
+    {"FileMenu", NULL, N_("_File"), NULL, "", NULL},
+    {"Quit", GTK_STOCK_QUIT, N_("_Quit"), NULL, "", G_CALLBACK(cb_quit)},
+    {"TestMenu", NULL, N_("_Test"), NULL, "", NULL},
+    {"RunAllTests", GTK_STOCK_REDO, N_("_Run all tests"), NULL, "",
+      G_CALLBACK(cb_run_all_tests)},
+    {"RunTest", GTK_STOCK_REDO, N_("_Run test"), NULL, "",
+      G_CALLBACK(cb_run_test)},
+    {"HelpMenu", NULL, N_("_Help"), NULL, "", NULL},
+    {"Website", NULL, N_("_Website"), NULL, "", NULL},
+    {"WebsiteEn", NULL, N_("_Website English"), NULL, "",
+     G_CALLBACK(cb_show_uri)},
+    {"WebsiteJa", NULL, N_("_Website Japanese"), NULL, "",
+     G_CALLBACK(cb_show_uri)},
+    {"Tutorial", NULL, N_("_Tutorial"), NULL, "", NULL},
+    {"TutorialEn", NULL, N_("_Tutorial English"), NULL, "",
+     G_CALLBACK(cb_show_uri)},
+    {"TutorialJa", NULL, N_("_Tutorial Japanese"), NULL, "",
+     G_CALLBACK(cb_show_uri)},
+    {"Reference", NULL, N_("_Reference"), NULL, "", NULL},
+    {"ReferenceEn", NULL, N_("_Reference English"), NULL, "",
+     G_CALLBACK(cb_show_uri)},
+    {"ReferenceJa", NULL, N_("_Reference Japanese"), NULL, "",
+     G_CALLBACK(cb_show_uri)}
+};
+
+static void
+load_actions (CutGtkUI *ui, GtkUIManager *ui_manager)
+{
+    GtkActionGroup *action_group;
+    gint i;
+
+    action_group = gtk_action_group_new("MenuActions");
+
+    for (i = 0; i < G_N_ELEMENTS(menu_entries); i++) {
+        gtk_action_group_add_actions(action_group, &(menu_entries[i]), 1, ui);
+    }
+    gtk_ui_manager_insert_action_group(ui_manager, action_group, 0);
+
+    g_object_unref(action_group);
+}
+
+static void
+load_ui_file (GtkUIManager *ui_manager)
+{
+    const gchar *ui_data_dir;
+    gchar *ui_file;
+
+    ui_data_dir = g_getenv("CUT_UI_DATA_DIR");
+    if (!ui_data_dir) {
+#ifdef G_OS_WIN32
+        ui_data_dir = cut_win32_ui_data_dir();
+#else
+        ui_data_dir = UI_DATA_DIR;
+#endif
+    }
+
+    ui_file = g_build_filename(ui_data_dir, "gtk-menu.ui", NULL);
+    gtk_ui_manager_add_ui_from_file(ui_manager, ui_file, NULL);
+    g_free(ui_file);
+}
+
+static void
+setup_menu_bar (GtkBox *box, CutGtkUI *ui)
+{
+    GtkUIManager *ui_manager;
+    GtkWidget *menu_bar;
+
+    ui_manager = gtk_ui_manager_new();
+    load_actions(ui, ui_manager);
+    load_ui_file(ui_manager);
+    gtk_window_add_accel_group(GTK_WINDOW(ui->window),
+                               gtk_ui_manager_get_accel_group(ui_manager));
+
+    menu_bar = gtk_ui_manager_get_widget(ui_manager, "/menu-bar");
+    if (menu_bar) {
+        gtk_box_pack_start(GTK_BOX(box), menu_bar, FALSE, FALSE, 0);
+    }
+
+    g_object_unref(ui_manager);
+}
+
 static void
 setup_cancel_or_restart_button (GtkToolbar *toolbar, CutGtkUI *ui)
 {
@@ -272,15 +459,15 @@ setup_top_bar (GtkBox *box, CutGtkUI *ui)
 {
     GtkWidget *hbox, *toolbar;
 
+    toolbar = gtk_toolbar_new();
+    gtk_toolbar_set_show_arrow(GTK_TOOLBAR(toolbar), FALSE);
+    gtk_box_pack_start(GTK_BOX(box), toolbar, FALSE, TRUE, 0);
+    setup_cancel_or_restart_button(GTK_TOOLBAR(toolbar), ui);
+
     hbox = gtk_hbox_new(FALSE, 0);
     gtk_box_pack_start(box, hbox, FALSE, TRUE, 0);
 
     setup_progress_bar(GTK_BOX(hbox), ui);
-
-    toolbar = gtk_toolbar_new();
-    gtk_toolbar_set_show_arrow(GTK_TOOLBAR(toolbar), FALSE);
-    gtk_box_pack_end(GTK_BOX(hbox), toolbar, FALSE, FALSE, 0);
-    setup_cancel_or_restart_button(GTK_TOOLBAR(toolbar), ui);
 }
 
 static void
@@ -295,7 +482,7 @@ setup_summary_label (GtkBox *box, CutGtkUI *ui)
 }
 
 static void
-setup_tree_view_columns (GtkTreeView *tree_view)
+setup_all_test_result_view_columns (GtkTreeView *tree_view)
 {
     GtkCellRenderer *renderer;
     GtkTreeViewColumn *column;
@@ -336,8 +523,8 @@ setup_tree_view_columns (GtkTreeView *tree_view)
     gtk_tree_view_append_column(tree_view, column);
 }
 
-static void
-setup_tree_view (GtkBox *box, CutGtkUI *ui)
+static GtkWidget *
+create_all_test_result_view (CutGtkUI *ui)
 {
     GtkWidget *tree_view, *scrolled_window;
     GtkTreeStore *tree_store;
@@ -346,7 +533,6 @@ setup_tree_view (GtkBox *box, CutGtkUI *ui)
     gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrolled_window),
                                    GTK_POLICY_AUTOMATIC,
                                    GTK_POLICY_AUTOMATIC);
-    gtk_box_pack_start(box, scrolled_window, TRUE, TRUE, 0);
 
     tree_store = gtk_tree_store_new(N_COLUMN,
                                     G_TYPE_STRING,
@@ -362,7 +548,35 @@ setup_tree_view (GtkBox *box, CutGtkUI *ui)
     tree_view = gtk_tree_view_new_with_model(GTK_TREE_MODEL(tree_store));
     gtk_container_add(GTK_CONTAINER(scrolled_window), tree_view);
     ui->tree_view = GTK_TREE_VIEW(tree_view);
-    setup_tree_view_columns(ui->tree_view);
+    setup_all_test_result_view_columns(ui->tree_view);
+
+    return scrolled_window;
+}
+
+static GtkWidget *
+create_partial_test_result_view (CutGtkUI *ui)
+{
+    GtkWidget *scrolled_window;
+
+    scrolled_window = gtk_scrolled_window_new(NULL, NULL);
+    return scrolled_window;
+}
+
+static void
+setup_test_result_view (GtkBox *box, CutGtkUI *ui)
+{
+    GtkWidget *hpaned;
+    GtkWidget *all_test_result_view, *partial_test_result_view;
+
+    hpaned = gtk_hpaned_new();
+
+    all_test_result_view = create_all_test_result_view(ui);
+    partial_test_result_view = create_partial_test_result_view(ui);
+
+    gtk_paned_pack1(GTK_PANED(hpaned), all_test_result_view, TRUE, TRUE);
+    gtk_paned_pack2(GTK_PANED(hpaned), partial_test_result_view, TRUE, TRUE);
+
+    gtk_box_pack_start(box, hpaned, TRUE, TRUE, 0);
 }
 
 static void
@@ -416,9 +630,10 @@ setup_window (CutGtkUI *ui)
     vbox = gtk_vbox_new(FALSE, 0);
     gtk_container_add(GTK_CONTAINER(window), vbox);
 
+    setup_menu_bar(GTK_BOX(vbox), ui);
     setup_top_bar(GTK_BOX(vbox), ui);
     setup_summary_label(GTK_BOX(vbox), ui);
-    setup_tree_view(GTK_BOX(vbox), ui);
+    setup_test_result_view(GTK_BOX(vbox), ui);
     setup_statusbar(GTK_BOX(vbox), ui);
 
     gtk_window_set_focus(GTK_WINDOW(window), GTK_WIDGET(ui->tree_view));
